<script setup name="manage">
import { ref, reactive, computed, watch, nextTick, onMounted } from "vue";
import info from '@/components/info.vue';
import bar from '@/components/echarts/bar5.vue';

const props = defineProps({
  data: {
    type: Object,
    default: {},
  },
});


const pOption = [
  {
    label: "站点ID",
    props: "stationId",
  },
  {
    label: "站点名称",
    props: "stationName",
  },
  {
    label: "电源设备IP",
    props: "powerIp",
  },
  {
    label: "电源设备名称",
    props: "powerName",
  },
  {
    label: "生产厂家",
    props: "company",
  },
  {
    label: "电源型号",
    props: "powerModel",
  },
  {
    label: "投入使用日期",
    props: "powerInuseTimeStr",
  },
  {
    label: "电源ID",
    props: "powerId",
  },
];

const bOption = [
  {
    label: "站点ID",
    props: "stationId",
  },
  {
    label: "站点名称",
    props: "stationName",
  },
  {
    label: "标称容量",
    props: "moncapstd",
  },
  {
    label: "单体电压",
    props: "monvolstd",
  },
  {
    label: "标称单体内阻",
    props: "monresstd",
  },
  // {
  //   label: "电池生产日期",
  //   props: "",
  // },
  {
    label: "投入使用日期",
    props: "inuseTimeStr",
  },
  {
    label: "电池品牌",
    props: "product",
  },
  {
    label: "电池型号",
    props: "battModel",
  },
  {
    label: "设备IP",
    props: "devIp",
  },
  {
    label: "设备ID",
    props: "devId",
  },
  {
    label: "电池组ID",
    props: "battgroupId",
  },
];

const rtInfo = computed(() => {
  let binf = props.data.binf || {};
  let pinf = props.data.pinf || {};
  let sinf = props.data.sinf || {};
  return {
    ...sinf,
    ...pinf,
    ...binf,
    inuseTimeStr: binf.inuseTime ? binf.inuseTime.substring(0, 10) : "",
    powerInuseTimeStr: pinf.powerInuseTime ? pinf.powerInuseTime.substring(0, 10) : "",
  }
});




onMounted(() => {

});
</script>

<template>
  <div class="tab-content">
    <div class="p-left">
      <card title="电源信息">
        <template #tools>
          <div class="btn">电源信息管理</div>
        </template>
        <div class="main">
          <div class="info">
            <div class="row" v-for="(p, idx) in pOption" :key="'p_' + idx">
              <div class="label">{{ p.label }}</div>
              <div class="value">{{ rtInfo[p.props] }}</div>
            </div>
          </div>
        </div>
      </card>
    </div>
    <div class="p-right">
      <card title="电池信息">
        <template #tools>
          <div class="btn">电池信息管理</div>
        </template>
        <div class="main">
          <div class="info">
            <div class="row" v-for="(b, idx) in bOption" :key="'b_' + idx">
              <div class="label">{{ b.label }}</div>
              <div class="value">{{ rtInfo[b.props] }}</div>
            </div>
          </div>
        </div>
      </card>
    </div>
  </div>
</template>

<style scoped lang="less">
.tab-content {
  display: flex;
  flex-direction: row;
  height: 100%;
  padding: 10px;

  .btn {
    background: linear-gradient(69deg, #6EABE4, #6EABE4 25%, #0A3E77 75%, #0A3E77);
    border: 1px solid #4D81BA;
    display: inline-block;
    font-size: 14px;
    padding: 4px 10px;
    color: #fff;
    cursor: pointer;
  }

  .main {
    padding: 40px 18px 10px 18px;
  }
  .info {
    border: 1px solid #146C9C;
    padding: 4px;
    .row {
      display: flex;
      height: 36px;
      flex-direction: row;
      background: rgba(0, 0, 0, 0.1);
      font-size: 14px;
      .label {
        background: rgba(7,111,232, 0.5);
        width: 180px;
        color: #fff;
        display: flex;
        align-items: center;
        justify-content: center;
        margin-right: 2em;
      }
      .value {
        flex: 1;
        display: flex;
        align-items: center;
      }
      &:nth-child(2n) {
        background: rgba(200, 200, 255, 0.1);
      }
      &:hover {
        background: rgba(200, 200, 255, 0.2);
      }
    }
  }

  .p-left {
    flex: 1;
    display: flex;
    flex-direction: column;
    margin-right: 10px;

  }
  .p-right {
    flex: 1;
    display: flex;
    flex-direction: column;
  }

}
</style>
